package com.study.libs;

import android.app.Activity;
import android.app.Application;
import android.os.Bundle;
import android.view.LayoutInflater;

import androidx.annotation.NonNull;
import androidx.core.view.LayoutInflaterCompat;

import com.study.libs.utils.SkinThemeUtils;

import java.lang.reflect.Field;
import java.util.HashMap;
import java.util.Observable;

public class ActivityLifeCycleCallback implements Application.ActivityLifecycleCallbacks {
    private Observable observable;
    private HashMap<Activity, SkinLayoutInflaterFactory> inflaterFactory;

    public ActivityLifeCycleCallback(@NonNull Observable observable) {
        this.observable = observable;
        inflaterFactory = new HashMap<>();
    }

    @Override
    public void onActivityCreated(Activity activity, Bundle savedInstanceState) {
        //先更改status bar
        SkinThemeUtils.updateStatusBarColor(activity);
        LayoutInflater layoutInflater = activity.getLayoutInflater();
        //反射属性，让LayoutInflater可以成功set好工厂。
        try {
            Field field = LayoutInflater.class.getDeclaredField("mFactorySet");
            field.setAccessible(true);
            field.setBoolean(layoutInflater, false);
        } catch (NoSuchFieldException | IllegalAccessException e) {
            e.printStackTrace();
        }
        //创建工厂，并且
        SkinLayoutInflaterFactory factory = new SkinLayoutInflaterFactory(activity);
        LayoutInflaterCompat.setFactory2(layoutInflater, factory);
        inflaterFactory.put(activity, factory);
        observable.addObserver(factory);//增加一个观察者
    }

    @Override
    public void onActivityStarted(Activity activity) {

    }

    @Override
    public void onActivityResumed(Activity activity) {

    }

    @Override
    public void onActivityPaused(Activity activity) {

    }

    @Override
    public void onActivityStopped(Activity activity) {

    }

    @Override
    public void onActivitySaveInstanceState(Activity activity, Bundle outState) {

    }

    @Override
    public void onActivityDestroyed(Activity activity) {
        SkinLayoutInflaterFactory factory = inflaterFactory.remove(activity);
        SkinManager.getInstance().deleteObserver(factory);
    }
}
